@@ -1,7 +1,7 @@
 from datetime import datetime
 from typing import List, Dict, Optional, ClassVar, Any
 from pydantic import BaseModel, Field, field_validator, model_validator
-from ...base_models.chatty_asset_model import ChattyAssetModel, ChattyAssetPreview
+from ...base_models.chatty_asset_model import ChattyAssetPreview, CompanyAssetModel
 from ...utils.types.identifier import StrObjectId
 from ...utils.definitions import Area
 from ...utils.types.serializer_type import SerializerType
@@ -63,7 +63,7 @@ class TemplateCampaignPreview(ChattyAssetPreview):
             self.progress = self.q_processed_recipients / self.q_recipients
         return self
 
-class TemplateCampaign(ChattyAssetModel):
+class TemplateCampaign(CompanyAssetModel):
     template_name: str
     name: str
     area: Area
