@@ -39,21 +39,21 @@ class ContextBuilder:
         return context
 
     @staticmethod
-    def contexts_prompt(contexts: List[ContextItem], chat:Chat) -> str:
+    def contexts_prompt(contexts: List[ContextItem]) -> str:
         context = ""
         for context_item in contexts:
             context += f"\n\n{context_item.name}: {context_item.content}"
         return context
 
     @staticmethod
-    def faqs_prompt(faqs: List[FAQ], chat:Chat) -> str:
+    def faqs_prompt(faqs: List[FAQ]) -> str:
         context = f"\n\nHere are the FAQ:"
         for faq_index, faq in enumerate(faqs):
             context += f"\n{faq_index + 1}. user: {faq.question}\nAI: {faq.answer}"
         return context
 
     @staticmethod
-    def examples_prompt(examples: List[ChatExample], chat:Chat) -> str:
+    def examples_prompt(examples: List[ChatExample]) -> str:
         context = f"\n\nHere are the examples of how you should reason (chain of thought) based on the user's messages and answer accordingly. This is the type of reasoning you're expected to do and add to your answer's chain of thought."
         for example_index, example in enumerate(examples):
             context += f"\n{example_index + 1}. {example.name}\n"
