@@ -19,7 +19,7 @@ class ProductFactory:
         if not company_id:
             raise ValueError("Company ID is required")
         clean_dict_product["company_id"] = company_id
-        base_fields = ["name", "price", "information", "external_id", "color", "parameters", "company_id", "created_at", "updated_at", "deleted_at", "id", "_id"]
+        base_fields = ["name", "price", "description", "external_id", "color", "parameters", "company_id", "created_at", "updated_at", "deleted_at", "id", "_id"]
         parameters = dict_product.get("parameters")
         if parameters and not isinstance(parameters, dict):
             raise ValueError("Parameters field must be a dictionary")
